#include <gtkmm.h>

#include "TransparentWindow.h"
#include "img/gtk-logo.h"

TransparentWindow::TransparentWindow()
{
	//
	// アイコン画像をロードしてGtk::Imageに貼り付けます。
	// Gtk::Imageをウィンドウのルート・コンテナとして追加します。
	//
	Glib::RefPtr<Gdk::PixbufLoader> loader = Gdk::PixbufLoader::create();
	loader->write(gtk_logo_png, gtk_logo_png_len);
	loader->close();
	Glib::RefPtr<Gdk::Pixbuf> buf = loader->get_pixbuf();
	m_image.set(buf);
	add(m_image);

	//
	// タイトルバーなどのウィンドウ装飾を外してウィンドウのクライアント領域のみが表示されるようにします。
	//
	set_decorated(false);

	//
	// アプリケーションによる描画をおこなうようにします。
	// これを指定しないと既定のカラーでウィンドウの背景が描画されてしまいます。
	//
	set_app_paintable(true);

	//
	// アルファチャンネル付きのウィンドウを作成するためのビジュアルを取得して、ウィンドウに設定します。
	// gtkmm(C++)にはGdk::Visualを取得するためのget_rgba_visual関数がありますが、
	// なぜかGdk::Visualを設定するための関数がありません。
	// 仕方がないのでgtk+(C)の関数である gtk_widget_set_visual関数を直接呼び出します。
	// (サンプルコードでは省略していますが、この処理はon_screen_changedでも実行する必要があります)
	//
	Glib::RefPtr<Gdk::Visual> visual = get_screen()->get_rgba_visual();
	gtk_widget_set_visual(GTK_WIDGET(gobj()), visual->gobj());

	//
	// ウィンドウとすべての子ウィジェットを表示します。
	//
	show_all();
}

TransparentWindow::~TransparentWindow()
{
}
